"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const utils_1 = require("@morjs/utils");
const path_1 = tslib_1.__importDefault(require("path"));
async function StyleLoader(fileContent) {
    const cb = this.async();
    const { userConfig, entryBuilder, runner } = this.getOptions();
    const entry = entryBuilder.getEntryByFilePath(this.resourcePath);
    const pluginOptions = {
        userConfig,
        loaderContext: this,
        fileInfo: {
            path: this.resourcePath,
            content: fileContent,
            extname: entry ? entry.extname : path_1.default.extname(this.resourcePath),
            entryName: entry ? entry.fullEntryName : undefined,
            entryFileType: entry ? entry.entryFileType : undefined,
            entryType: entry ? entry.entryType : utils_1.EntryType.unknown
        }
    };
    // 构造 postcss 的插件
    const plugins = runner.hooks.styleParser.isUsed()
        ? await runner.hooks.styleParser.promise([], pluginOptions)
        : [];
    if (plugins.length) {
        try {
            fileContent = (await utils_1.postcss
                .default(plugins)
                .process(fileContent, {
                from: this.resourcePath
            })
                .async()).css;
        }
        catch (error) {
            utils_1.logger.error(`处理样式出错: ${this.resourcePath}`, { error });
            return cb(error);
        }
    }
    cb(null, fileContent);
}
exports.default = StyleLoader;
//# sourceMappingURL=styleLoader.js.map